class ProposalActionsController < ApplicationController
  before_action :set_action_and_reasons, only: [:show, :edit, :update, :destroy, :doit]

  def index
    params[:hidecat] ||= [] # defaults to empty array
    @actions = ProposalAction.with_score
    
    # filters
    @actions = @actions.where(zavrhnut: false)
    @actions = @actions.where(zone: params[:zone]) unless params[:zone].nil?
    @actions = @actions.where(zone: params[:zones]) unless params[:zones].nil?
    @actions = @actions.reject{|action| params[:hidecat].include?(action.category)}
    
    # paginate
    @actions = @actions.paginate(:page=>params[:page], :per_page=>(params[:per_page] || 30))
    @categories = ProposalAction.group(:category).count.collect{|item| item[0]}
  end
  
  def show
    @capitalized_action_name = (@action.action[0].upcase + @action.action[1..-1]).html_safe
  end
  
  def destroy
    @action.destroy
    redirect_to proposal_actions_url
  end

  def update
    if @action.update(proposal_action_params)
      redirect_to @action, notice: 'Proposal was successfully updated.'
    else
      render action: 'edit'
    end
  end
  
  def doit
    if @action.doit
      redirect_to @action.followup_url, notice: 'Akce byla úspěšně vykonána.'
      @action.destroy
    else
      redirect_to action: 'show', notice: 'Akce nebyla úspěšná!' 
    end
  end
  
  def edit
  end
    
  private
    # Use callbacks to share common setup or constraints between actions.
    def set_action_and_reasons
      @action = ProposalAction.find(params[:id])
      @reasons = @action.reasons
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def proposal_action_params
      params.require(:proposal_action).permit(:reason, :action, :category, :catid, :url, :zavrhnut)
    end

end
